@@ -5,7 +5,7 @@ use warnings;
 use base qw(VFSsimple::Base);
 use File::Copy ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -45,6 +45,11 @@ sub drv_open {
     }
 }
 
+sub exists {
+    my ($self, $file) = @_;
+    return(stat("$self->{realroot}/$file") != 0);
+}
+
 1;
 
 __END__
